[Bf-blender-cvs] [a272a2a6cdc] master: Cleanup: spelling

Campbell Barton noreply at git.blender.org
Fri Jul 3 04:06:24 CEST 2020


Commit: a272a2a6cdc30c30d3957787f30211cfc5b9d35c
Author: Campbell Barton
Date:   Fri Jul 3 11:20:52 2020 +1000
Branches: master
https://developer.blender.org/rBa272a2a6cdc30c30d3957787f30211cfc5b9d35c

Cleanup: spelling

===================================================================

M	intern/ghost/intern/GHOST_Window.h
M	intern/mantaflow/intern/strings/fluid_script.h
M	source/blender/blenlib/intern/BLI_kdopbvh.c
M	source/blender/editors/sculpt_paint/sculpt.c
M	source/blender/editors/space_outliner/outliner_draw.c
M	source/blender/editors/space_outliner/outliner_intern.h
M	source/blender/makesdna/intern/makesdna.c
M	source/blender/makesrna/intern/rna_key.c

===================================================================

diff --git a/intern/ghost/intern/GHOST_Window.h b/intern/ghost/intern/GHOST_Window.h
index 472149148e6..6738aa850ce 100644
--- a/intern/ghost/intern/GHOST_Window.h
+++ b/intern/ghost/intern/GHOST_Window.h
@@ -34,7 +34,7 @@ class GHOST_Context;
  * Dimensions are given in screen coordinates that are relative to the
  * upper-left corner of the screen.
  * Implements part of the GHOST_IWindow interface and adds some methods to
- * be implemented by childs of this class.
+ * be implemented by sub-classes of this class.
  */
 class GHOST_Window : public GHOST_IWindow {
  public:
diff --git a/source/blender/blenlib/intern/BLI_kdopbvh.c b/source/blender/blenlib/intern/BLI_kdopbvh.c
index 40b011dca9e..0707e4c1d2a 100644
--- a/source/blender/blenlib/intern/BLI_kdopbvh.c
+++ b/source/blender/blenlib/intern/BLI_kdopbvh.c
@@ -94,7 +94,7 @@ typedef struct BVHNode {
 struct BVHTree {
   BVHNode **nodes;
   BVHNode *nodearray;  /* pre-alloc branch nodes */
-  BVHNode **nodechild; /* pre-alloc childs for nodes */
+  BVHNode **nodechild; /* pre-alloc children for nodes */
   float *nodebv;       /* pre-alloc bounding-volumes for nodes */
   float epsilon;       /* epslion is used for inflation of the k-dop      */
   int totleaf;         /* leafs */
diff --git a/source/blender/editors/sculpt_paint/sculpt.c b/source/blender/editors/sculpt_paint/sculpt.c
index 2873f2003cf..178b29edfff 100644
--- a/source/blender/editors/sculpt_paint/sculpt.c
+++ b/source/blender/editors/sculpt_paint/sculpt.c
@@ -682,9 +682,9 @@ static void sculpt_vertex_neighbors_get_grids(SculptSession *ss,
                                               const bool include_duplicates,
                                               SculptVertexNeighborIter *iter)
 {
-  /* TODO: optimize this. We could fill SculptVertexNeighborIter directly,
+  /* TODO: optimize this. We could fill #SculptVertexNeighborIter directly,
    * maybe provide coordinate and mask pointers directly rather than converting
-   * back and forth between CCGElem and global index. */
+   * back and forth between #CCGElem and global index. */
   const CCGKey *key = BKE_pbvh_get_grid_key(ss->pbvh);
   const int grid_index = index / key->grid_area;
   const int vertex_index = index - grid_index * key->grid_area;
@@ -777,7 +777,7 @@ bool SCULPT_vertex_is_boundary(SculptSession *ss, const int index)
   return true;
 }
 
-/* Utils */
+/* Utilities */
 
 /**
  * Returns true when the step belongs to the stroke that is directly performed by the brush and
@@ -1380,9 +1380,10 @@ static void paint_mesh_restore_co(Sculpt *sd, Object *ob)
   BKE_pbvh_search_gather(ss->pbvh, NULL, NULL, &nodes, &totnode);
 
   /**
-   * Disable OpenMP when dynamic-topology is enabled. Otherwise, new entries might be inserted by
-   * #SCULPT_undo_push_node() into the #GHash used internally by #BM_log_original_vert_co()
-   * by a different thread. See T33787. */
+   * Disable multi-threading when dynamic-topology is enabled. Otherwise,
+   * new entries might be inserted by #SCULPT_undo_push_node() into the #GHash
+   * used internally by #BM_log_original_vert_co() by a different thread. See T33787.
+   */
   SculptThreadedTaskData data = {
       .sd = sd,
       .ob = ob,
@@ -1403,11 +1404,11 @@ static void paint_mesh_restore_co(Sculpt *sd, Object *ob)
 
 static void sculpt_extend_redraw_rect_previous(Object *ob, rcti *rect)
 {
-  /* Expand redraw rect with redraw rect from previous step to
+  /* Expand redraw \a rect with redraw \a rect from previous step to
    * prevent partial-redraw issues caused by fast strokes. This is
    * needed here (not in sculpt_flush_update) as it was before
    * because redraw rectangle should be the same in both of
-   * optimized PBVH draw function and 3d view redraw (if not -- some
+   * optimized PBVH draw function and 3d view redraw, if not -- some
    * mesh parts could disappear from screen (sergey). */
   SculptSession *ss = ob->sculpt;
 
@@ -1448,8 +1449,8 @@ void ED_sculpt_redraw_planes_get(float planes[4][4], ARegion *region, Object *ob
 
   paint_calc_redraw_planes(planes, region, ob, &rect);
 
-  /* We will draw this rect, so now we can set it as the previous partial rect.
-   * Note that we don't update with the union of previous/current (rect), only with
+  /* We will draw this \a rect, so now we can set it as the previous partial \a rect.
+   * Note that we don't update with the union of previous/current (\a rect), only with
    * the current. Thus we avoid the rectangle needlessly growing to include
    * all the stroke area. */
   ob->sculpt->cache->previous_r = ob->sculpt->cache->current_r;
@@ -2397,7 +2398,7 @@ float SCULPT_brush_strength_factor(SculptSession *ss,
   /* Paint mask. */
   avg *= 1.0f - mask;
 
-  /* Automasking. */
+  /* Auto-masking. */
   avg *= SCULPT_automasking_factor_get(ss, vertex_index);
 
   return avg;
@@ -2639,7 +2640,7 @@ static void calc_brush_local_mat(const Brush *brush, Object *ob, float local_mat
   float angle, v[3];
   float up[3];
 
-  /* Ensure ob->imat is up to date. */
+  /* Ensure `ob->imat` is up to date. */
   invert_m4_m4(ob->imat, ob->obmat);
 
   /* Initialize last column of matrix. */
@@ -2669,8 +2670,7 @@ static void calc_brush_local_mat(const Brush *brush, Object *ob, float local_mat
   scale_m4_fl(scale, cache->radius);
   mul_m4_m4m4(tmat, mat, scale);
 
-  /* Return inverse (for converting from modelspace coords to local
-   * area coords). */
+  /* Return inverse (for converting from model-space coords to local area coords). */
   invert_m4_m4(local_mat, tmat);
 }
 
@@ -3454,7 +3454,7 @@ static void do_pinch_brush_task_cb_ex(void *__restrict userdata,
       float disp_center[3];
       float x_disp[3];
       float z_disp[3];
-      /* Calcualte displacement from the vertex to the brush center. */
+      /* Calculate displacement from the vertex to the brush center. */
       sub_v3_v3v3(disp_center, test.location, vd.co);
 
       /* Project the displacement into the X vector (aligned to the stroke). */
@@ -3463,8 +3463,8 @@ static void do_pinch_brush_task_cb_ex(void *__restrict userdata,
       /* Project the displacement into the Z vector (aligned to the surface normal). */
       mul_v3_v3fl(z_disp, z_object_space, dot_v3v3(disp_center, z_object_space));
 
-      /* Add the two projected vectors to calculate the final displacement. The Y component is
-       * removed */
+      /* Add the two projected vectors to calculate the final displacement.
+       * The Y component is removed. */
       add_v3_v3v3(disp_center, x_disp, z_disp);
 
       if (brush->falloff_shape == PAINT_FALLOFF_SHAPE_TUBE) {
@@ -3500,7 +3500,7 @@ static void do_pinch_brush(Sculpt *sd, Object *ob, PBVHNode **nodes, int totnode
     return;
   }
 
-  /* Init mat */
+  /* Initialize `mat`. */
   cross_v3_v3v3(mat[0], area_no, ss->cache->grab_delta_symmetry);
   mat[0][3] = 0.0f;
   cross_v3_v3v3(mat[1], area_no, mat[0]);
@@ -3803,7 +3803,7 @@ void SCULPT_calc_brush_plane(
     }
 
     /* For flatten center. */
-    /* fFlatten center has not been calculated yet if we are not using the area normal. */
+    /* Flatten center has not been calculated yet if we are not using the area normal. */
     if (brush->sculpt_plane != SCULPT_DISP_DIR_AREA) {
       calc_area_center(sd, ob, nodes, totnode, r_area_co);
     }
@@ -4232,9 +4232,9 @@ static void do_layer_brush_task_cb_ex(void *__restrict userdata,
         disp_factor = &ss->cache->layer_displacement_factor[vi];
       }
 
-      /* When using persistent base, the layer brush Ctrl invert mode resets the height of the
-       * layer to 0. This makes possible to clean edges of previously added layers on top of the
-       * base. */
+      /* When using persistent base, the layer brush (holding Control) invert mode resets the
+       * height of the layer to 0. This makes possible to clean edges of previously added layers
+       * on top of the base. */
       /* The main direction of the layers is inverted using the regular brush strength with the
        * brush direction property. */
       if (use_persistent_base && ss->cache->invert) {
@@ -4791,7 +4791,7 @@ static void do_clay_strips_brush(Sculpt *sd, Object *ob, PBVHNode **nodes, int t
   float area_co_displaced[3];
   madd_v3_v3v3fl(area_co_displaced, area_co, area_no, -radius * 0.7f);
 
-  /* Init brush local space matrix. */
+  /* Initialize brush local-space matrix. */
   cross_v3_v3v3(mat[0], area_no, ss->cache->grab_delta_symmetry);
   mat[0][3] = 0.0f;
   cross_v3_v3v3(mat[1], area_no, mat[0]);
@@ -5153,7 +5153,7 @@ static void do_clay_thumb_brush(Sculpt *sd, Object *ob, PBVHNode **nodes, int to
   mul_v3_fl(temp, displace);
   add_v3_v3(area_co, temp);
 
-  /* Init brush local space matrix. */
+  /* Initialize brush local-space matrix. */
   cross_v3_v3v3(mat[0], area_no, ss->cache->grab_delta_symmetry);
   mat[0][3] = 0.0f;
   cross_v3_v3v3(mat[1], area_no, mat[0]);
@@ -5453,7 +5453,7 @@ static void do_brush_action(Sculpt *sd, Object *ob, Br

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-blender-cvs mailing list
diff --git a/intern/mantaflow/intern/strings/fluid_script.h b/intern/mantaflow/intern/strings/fluid_script.h
index 62274101859..b166ab585b0 100644
--- a/intern/mantaflow/intern/strings/fluid_script.h
+++ b/intern/mantaflow/intern/strings/fluid_script.h
@@ -461,14 +461,14 @@ if 'fluid_data_dict_resume_s$ID$' in globals(): fluid_data_dict_resume_s$ID$.cle
 if 'fluid_guiding_dict_s$ID$' in globals(): fluid_guiding_dict_s$ID$.clear()\n\
 if 'fluid_vel_dict_s$ID$' in globals(): fluid_vel_dict_s$ID$.clear()\n\
 \n\
-# Delete all childs from objects (e.g. pdata for particles)\n\
-mantaMsg('Release solver childs childs')\n\
+# Delete all children from objects (e.g. pdata for particles)\n\
+mantaMsg('Release solver childrens children')\n\
 for var in list(globals()):\n\
     if var.endswith('_pp$ID$') or var.endswith('_mesh$ID$'):\n\
         del globals()[var]\n\
 \n\
-# Now delete childs from solver objects\n\
-mantaMsg('Release solver childs')\n\
+# Now delete children from solver objects\n\
+mantaMsg('Release solver children')\n\
 for var in list(globals()):\n\
     if var.endswith('_s$ID$') or var.endswith('_sn$ID$') or var.endswith('_sm$ID$') or var.endswith('_sp$ID$') or var.endswith('_sg$ID$'):\n\
         del globals()[var]\n\